import curses
import curses.textpad
import datetime

from aneris_db_if import aneris_db_if

#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#

class aneris_tasks(object):
	
	def __init__(self, db_if, resources):
		self.m_db_if = db_if
		self.m_resources = resources
		self.m_tasks = db_if.read_task_data()
		self.m_tasks_visible = True
		self.m_task_cursor=0
		self.m_delete_armed=False

#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#
		
	def render(self, window, active):
		height, width = window.getmaxyx()

		window.clear()
		
		if(active == True):
			for y in range(0, height):
				window.addstr(y, 0, " ", curses.A_REVERSE|curses.color_pair(7))
			window.addstr(3, 1, ">>", curses.A_BOLD|curses.A_REVERSE|curses.color_pair(7))

		window.addstr(0, 2, "work list: {0}".format(str(datetime.date.today())), curses.A_BOLD|curses.color_pair(4))
		for x in range(0, len("work list: {0}".format(str(datetime.date.today())))):
			window.addstr(1, x+2, "=", curses.A_BOLD|curses.color_pair(4))
		
		y = 3
		cumulative_hours_remaining = 0
		for task_index in range(0, len(self.m_tasks)):
			if(y == height):
				break
				
			if(self.m_tasks[task_index]["is_a_project"] == True):
				project_hours_remaining = 0
				for task_jndex in range(task_index+1, len(self.m_tasks)):
					if(self.m_tasks[task_jndex]["is_a_project"] == True):
						break
					else:
						project_hours_remaining += self.m_tasks[task_jndex]["hours_work"]
				
				cumulative_hours_remaining += project_hours_remaining
				
				if(task_index >= self.m_task_cursor):
					project_completion_day = self.m_resources.hours_work_2_completion_day(cumulative_hours_remaining)
				
					if((self.m_delete_armed == True) and (y==3)):
						style=curses.A_BOLD|curses.A_REVERSE|curses.color_pair(5)
					else:
						if(project_completion_day > self.m_tasks[task_index]["deadline"]):
							style=curses.A_BOLD|curses.A_REVERSE|curses.color_pair(1)
						else:
							style=curses.A_BOLD|curses.A_REVERSE|curses.color_pair(2)
				
					if(project_completion_day > self.m_tasks[task_index]["deadline"]):
						window.addstr(y, 4, "{0} hours by {1} : expected {2} : {3} :  ~ LATE! ".format( \
										project_hours_remaining, \
										str(self.m_tasks[task_index]["deadline"]),\
										str(project_completion_day), \
										self.m_tasks[task_index]["text"]), style)
					else:
						window.addstr(y, 4, "{0} hours by {1} : expected {2} : {3} :  ~ OK ".format( \
										project_hours_remaining, \
										str(self.m_tasks[task_index]["deadline"]),\
										str(project_completion_day), \
										self.m_tasks[task_index]["text"]), style)
					y += 1
				
			else:
				if(task_index >= self.m_task_cursor):
					if((self.m_delete_armed == True) and (y==3)):
						style=curses.A_BOLD|curses.color_pair(5)
					else:
						style=curses.color_pair(7)
						
					if(self.m_tasks_visible == True):
						if((task_index == len(self.m_tasks)-1) or (self.m_tasks[task_index+1]["is_a_project"] == True)):
							window.addch(y, 4, curses.ACS_LLCORNER)
						else:
							window.addch(y, 4, curses.ACS_LTEE)
						window.addstr(y, 5, "{0} : {1} hours remaining".format(self.m_tasks[task_index]["text"], self.m_tasks[task_index]["hours_work"]), style)
						y += 1

	def get_text(self, edit_window, prompt, init_text):
		height, width = edit_window.getmaxyx()
		edit_window.clear()
		edit_window.addstr(0, 0, ">>", curses.A_BOLD|curses.A_REVERSE|curses.color_pair(7))
		edit_window.addstr(0, 3, prompt, curses.A_BOLD|curses.color_pair(7))
		edit_window.refresh()

		curses.curs_set(1)

		textpad_window = curses.newwin(1, width-(len(prompt)+5), 1, (len(prompt)+5))
		textpad_window.clear()
		textpad_window.addstr(0, 0, init_text)
		new_text = curses.textpad.Textbox(textpad_window, insert_mode=True).edit().strip()
		del textpad_window

		curses.curs_set(0)

		edit_window.clear()
		return(new_text)

#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#

	def key_next_task(self):
		self.m_delete_armed=False
		if(self.m_task_cursor < len(self.m_tasks)):
			self.m_task_cursor += 1
			if(self.m_tasks_visible == False):
				while((self.m_task_cursor < len(self.m_tasks)) and (self.m_tasks[self.m_task_cursor]["is_a_project"] == False)):
					self.m_task_cursor += 1

	def key_previous_task(self):
		self.m_delete_armed=False
		if(self.m_task_cursor > 0):
			self.m_task_cursor -= 1
			if(self.m_tasks_visible == False):
				while((self.m_task_cursor > 0) and (self.m_tasks[self.m_task_cursor]["is_a_project"] == False)):
					self.m_task_cursor -= 1
				
	def key_toggle_task_visibility(self):
		self.m_delete_armed=False
		self.m_tasks_visible = not self.m_tasks_visible

#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#

	def key_increment(self):
		self.m_delete_armed=False
		if(self.m_task_cursor < len(self.m_tasks)):
			if(self.m_tasks[self.m_task_cursor]["is_a_project"] == False):
				self.m_tasks[self.m_task_cursor]["hours_work"] += 1
			else:
				project_indices = [ i for i, task in enumerate(self.m_tasks) if task["is_a_project"] == True ]
				project_index_cursor = project_indices.index(self.m_task_cursor)
				if(project_index_cursor > 0):
					project_indices.append(len(self.m_tasks))
				
					a=project_indices[project_index_cursor-1]
					b=project_indices[project_index_cursor]
					c=project_indices[project_index_cursor+1]
					
					self.m_tasks[b:c], self.m_tasks[a:a] = [], self.m_tasks[b:c]

	def key_decrement(self):
		self.m_delete_armed=False
		if(self.m_task_cursor < len(self.m_tasks)):
			if(self.m_tasks[self.m_task_cursor]["is_a_project"] == False):
				if(self.m_tasks[self.m_task_cursor]["hours_work"] > 0):
					self.m_tasks[self.m_task_cursor]["hours_work"] -= 1
			else:
				project_indices = [ i for i, task in enumerate(self.m_tasks) if task["is_a_project"] == True ]
				project_index_cursor = project_indices.index(self.m_task_cursor)
				if(project_index_cursor < len(project_indices)-1):
					project_indices.append(len(self.m_tasks))
					
					a=project_indices[project_index_cursor]
					b=project_indices[project_index_cursor+1]
					c=project_indices[project_index_cursor+2]
					
					self.m_tasks[b:c], self.m_tasks[a:a] = [], self.m_tasks[b:c]

#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#

	def key_add_project(self, edit_window):
		self.m_delete_armed=False
		self.m_tasks.insert(self.m_task_cursor, {})
		self.m_tasks[self.m_task_cursor]["text"] = ""
		self.m_tasks[self.m_task_cursor]["is_a_project"] = True
		self.m_tasks[self.m_task_cursor]["deadline"] = datetime.date.today()
		self.key_select(edit_window)
	
	def key_add_task(self, edit_window):
		if((self.m_task_cursor < len(self.m_tasks)) and (self.m_tasks[self.m_task_cursor]["is_a_project"] == True)):
			self.m_delete_armed=False
			self.m_task_cursor += 1

			self.m_tasks.insert(self.m_task_cursor, {})
			self.m_tasks[self.m_task_cursor]["text"] = ""
			self.m_tasks[self.m_task_cursor]["is_a_project"] = False
			self.m_tasks[self.m_task_cursor]["hours_work"] = 0
			self.key_select(edit_window)
			self.m_task_cursor -= 1
			
	def key_remove_task(self):
		if(self.m_task_cursor < len(self.m_tasks)):
			if((self.m_task_cursor > 0) or (len(self.m_tasks) == 1) or (self.m_tasks[self.m_task_cursor+1]["is_a_project"] == True)):
				if(self.m_delete_armed == False):
					self.m_delete_armed=True
				else:
					self.m_delete_armed=False
					del self.m_tasks[self.m_task_cursor]

#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#

	def key_select(self, edit_window):
		self.m_delete_armed=False
		
		if(self.m_tasks[self.m_task_cursor]["is_a_project"] == True):
			self.m_tasks[self.m_task_cursor]["text"] = self.get_text(edit_window, "project:", self.m_tasks[self.m_task_cursor]["text"])
			deadline_str=self.get_text(edit_window, "project deadline (yyyy-mm-dd):", str(self.m_tasks[self.m_task_cursor]["deadline"]))
			try:
				self.m_tasks[self.m_task_cursor]["deadline"] = datetime.datetime.strptime(deadline_str, "%Y-%m-%d").date()
			except ValueError:
				self.m_tasks[self.m_task_cursor]["deadline"] = datetime.date.today()
			
		else:
			self.m_tasks[self.m_task_cursor]["text"] = self.get_text(edit_window, "task:", self.m_tasks[self.m_task_cursor]["text"])
			hours_work_str=self.get_text(edit_window, "hours work:", str(self.m_tasks[self.m_task_cursor]["hours_work"]))
			try:
				self.m_tasks[self.m_task_cursor]["hours_work"] = int(hours_work_str)
			except ValueError:
				self.m_tasks[self.m_task_cursor]["hours_work"] = 0
		

#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#

	def save(self):
		self.m_db_if.write_task_data(self.m_tasks)




#!/usr/bin/python3

from distutils.core import setup

#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#
# Work around mbcs bug in distutils.
# http://bugs.python.org/issue10945

import codecs
try:
	codecs.lookup('mbcs')
except LookupError:
	ascii = codecs.lookup('ascii')
	func = lambda name, enc=ascii: {True: enc}.get(name=='mbcs')
	codecs.register(func)

#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#

setup(
	name = "aneris",
	packages = ["aneris"],
	version = "0.2",
	description = "curses time/project planner",
	author = "the_night_penguin",
	author_email = "of.many.devices@gmail.com",
	url = "http://pypi.python.org/pypi/aneris",
	keywords = ["time", "project", "planning"],
	classifiers = [
		"Programming Language :: Python",
		"Programming Language :: Python :: 3",
		"Development Status :: 3 - Alpha",
		"Environment :: Other Environment",
		"Intended Audience :: Developers",
		"License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
		"Operating System :: OS Independent",
		"Topic :: Office/Business :: Scheduling",
	],
)



import datetime
import curses

from aneris_workers import workers, work_days

#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#

class aneris_resources(object):

	def __init__(self, db_if):
		self.m_db_if = db_if
		self.m_worker_calendar_exceptions = db_if.read_worker_calendar_exception_data()
		self.m_worker_cursor_index = 0
		self.m_worker_cursor = list(workers.keys())[self.m_worker_cursor_index]
		self.m_day_cursor = datetime.date.today()
		
#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#

	def render(self, window, active):
		height, width = window.getmaxyx()

		window.clear()
		
		if(active == True):
			for y in range(0, height):
				window.addstr(y, 0, " ", curses.A_REVERSE|curses.color_pair(7))
			window.addstr(3, 1, ">>", curses.A_BOLD|curses.A_REVERSE|curses.color_pair(7))

		window.addstr(0, 2, "worker: {0}".format(self.m_worker_cursor), curses.A_BOLD|curses.color_pair(3))
		for x in range(0, len("worker: {0}".format(self.m_worker_cursor))):
			window.addstr(1, x+2, "=", curses.A_BOLD|curses.color_pair(3))

		y=3
		for i in range(0, height-3):
			day = self.m_day_cursor+datetime.timedelta(days=i)
			week_day = work_days[day.weekday()]
			if(day.weekday() in range(5, 7)):
				window.addstr(y, 4, "{0}\t {1}: {2} hours".format(week_day, day, self.get_committed_hours(self.m_worker_cursor, day)), curses.A_BOLD|curses.color_pair(4))
			else:
				window.addstr(y, 4, "{0}\t {1}: {2} hours".format(week_day, day, self.get_committed_hours(self.m_worker_cursor, day)), curses.color_pair(3))
			y += 1
			
#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#

	def key_next_worker(self):
		self.m_worker_cursor_index += 1
		if(self.m_worker_cursor_index == len(workers)):
			self.m_worker_cursor_index = 0
		self.m_worker_cursor = list(workers.keys())[self.m_worker_cursor_index]

	def key_next_day(self):
		self.m_day_cursor += datetime.timedelta(days=1)
		
	def key_previous_day(self):
		if(self.m_day_cursor > datetime.date.today()):
			self.m_day_cursor -= datetime.timedelta(days=1)

	def key_increment(self):
		self.m_worker_calendar_exceptions[self.m_day_cursor][self.m_worker_cursor] = self.get_worker_calendar_exception(self.m_worker_cursor, self.m_day_cursor)+1

	def key_decrement(self):
		self.m_worker_calendar_exceptions[self.m_day_cursor][self.m_worker_cursor] = self.get_worker_calendar_exception(self.m_worker_cursor, self.m_day_cursor)-1

#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#
	
	def get_worker_calendar_exception(self, worker, day):
		if((day in self.m_worker_calendar_exceptions) == False):
			self.m_worker_calendar_exceptions[day] = {}
			
		if((worker in self.m_worker_calendar_exceptions[day]) == False):
			self.m_worker_calendar_exceptions[day][worker] = self.get_default_committed_hours(worker, day)

		return(self.m_worker_calendar_exceptions[day][worker])

	def get_default_committed_hours(self, worker, day):
		week_day = work_days[day.weekday()]
		week_number = ((day-workers[worker]["default_committed_hours_start_date"]).days//7)
		
		if((week_day in workers[worker]["default_committed_hours"]) == True):
			default_committed_hours = workers[worker]["default_committed_hours"][week_day][week_number%len(workers[worker]["default_committed_hours"][week_day])]
		else:
			default_committed_hours = 0
			
		return(default_committed_hours)

	def get_committed_hours(self, worker, day):
		committed_hours = self.get_default_committed_hours(worker, day)
		
		if((day in self.m_worker_calendar_exceptions) == True):
			if((worker in self.m_worker_calendar_exceptions[day]) == True):
				committed_hours = self.m_worker_calendar_exceptions[day][worker]

		return(committed_hours)

	def hours_work_2_completion_day(self, hours_work):
		day=datetime.date.today()
		
		while(hours_work > 0):
			day += datetime.timedelta(days=1)
		
			for worker in workers:
				hours_work -= self.get_committed_hours(worker, day)
		
		return(day)
		
#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#

	def save(self):
		for day in self.m_worker_calendar_exceptions.keys():
			if(day<datetime.date.today()):
				del self.m_worker_calendar_exceptions[day]

		self.m_db_if.write_worker_calendar_exception_data(self.m_worker_calendar_exceptions)



import os.path
import pickle

#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#

class aneris_db_if(object):
	
	task_data_file_name = os.path.expanduser("~")+"/.aneris_task_data.p"
	worker_calendar_exception_data_file_name = os.path.expanduser("~")+"/.aneris_worker_calendar_exception_data.p"

#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#

	def write_task_data(self, task_data):
		with open(self.task_data_file_name, "wb") as task_data_write_fp:
			pickle.dump(task_data, task_data_write_fp)
			
	def read_task_data(self):
		if(os.path.exists(self.task_data_file_name) == True):
			with open(self.task_data_file_name, "rb") as task_data_read_fp:
				task_data = pickle.load(task_data_read_fp)
		else:
			task_data = []

		return(task_data)

#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#
		
	def write_worker_calendar_exception_data(self, worker_calendar_exception_data):
		with open(self.worker_calendar_exception_data_file_name, "wb") as worker_calendar_exception_data_write_fp:
			pickle.dump(worker_calendar_exception_data, worker_calendar_exception_data_write_fp)

			
	def read_worker_calendar_exception_data(self):
		if(os.path.exists(self.worker_calendar_exception_data_file_name) == True):
			with open(self.worker_calendar_exception_data_file_name, "rb") as worker_calendar_exception_data_read_fp:
				worker_calendar_exception_data = pickle.load(worker_calendar_exception_data_read_fp)
		else:
			worker_calendar_exception_data = {}
			
		return(worker_calendar_exception_data)
		



#!/usr/bin/python3

import time
import curses
import datetime

from aneris_tasks import aneris_tasks
from aneris_resources import aneris_resources
from aneris_db_if import aneris_db_if

#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#

def main_ui(stdscr):

	curses.init_pair(1, curses.COLOR_RED, curses.COLOR_BLACK)
	curses.init_pair(2, curses.COLOR_GREEN, curses.COLOR_BLACK)
	curses.init_pair(3, curses.COLOR_YELLOW, curses.COLOR_BLACK)
	curses.init_pair(4, curses.COLOR_BLUE, curses.COLOR_BLACK)
	curses.init_pair(5, curses.COLOR_MAGENTA, curses.COLOR_BLACK)
	curses.init_pair(6, curses.COLOR_CYAN, curses.COLOR_BLACK)
	curses.init_pair(7, curses.COLOR_WHITE, curses.COLOR_BLACK)
	
	curses.curs_set(0)

	db_if=aneris_db_if()
	resources=aneris_resources(db_if)
	tasks=aneris_tasks(db_if, resources)
	
	tasks_window_active = True
	resources_window_active = False

	while True:

		#paint screen
		try:
			stdscr.clear()
			height, width = stdscr.getmaxyx()

			edit_window = curses.newwin(1, width-2, 1, 1)
			tasks_window = curses.newwin((height-5)>>1, width-2, 3, 1)
			resources_window = curses.newwin((height-5)>>1, width-2, ((height-5)>>1)+4, 1)
			
			tasks.render(tasks_window, tasks_window_active)
			resources.render(resources_window, resources_window_active)
			
			stdscr.refresh()
			tasks_window.refresh()
			resources_window.refresh()
		except curses.error:
			pass
		
		#catch key input
		key=stdscr.getch()

		if key == curses.KEY_UP:
			if(tasks_window_active == True):
				tasks.key_previous_task()
			if(resources_window_active == True):
				resources.key_previous_day()
		elif key == curses.KEY_DOWN:
			if(tasks_window_active == True):
				tasks.key_next_task()
			if(resources_window_active == True):
				resources.key_next_day()

		elif key == curses.KEY_LEFT or key == ord('q'):
			break

		elif key == curses.KEY_RIGHT or key == ord('\n'):
			if(tasks_window_active == True):
				tasks.key_select(edit_window)

		elif key == ord('+'):
			if(tasks_window_active == True):
				tasks.key_increment()
			if(resources_window_active == True):
				resources.key_increment()
				
		elif key == ord('-'):
			if(tasks_window_active == True):
				tasks.key_decrement()
			if(resources_window_active == True):
				resources.key_decrement()

		elif key == ord(' '):
			if(tasks_window_active == True):
				tasks.key_toggle_task_visibility()
			if(resources_window_active == True):
				resources.key_next_worker()

		elif key == ord('a'):
			if(tasks_window_active == True):
				tasks.key_add_task(edit_window)
		elif key == ord('A'):
			if(tasks_window_active == True):
				tasks.key_add_project(edit_window)
		elif key == ord('r') or key == curses.KEY_BACKSPACE:
			if(tasks_window_active == True):
				tasks.key_remove_task()

		elif key == ord('\t'):
			tasks_window_active = not tasks_window_active
			resources_window_active = not resources_window_active

		elif key == ord('s'):
			try:
				edit_window.clear()
				edit_window.addstr(0, 0, "saved at {0}".format(datetime.datetime.now()), curses.color_pair(2))
				edit_window.refresh()
			except curses.error:
				pass
			tasks.save()
			resources.save()
			time.sleep(1)

		elif key == ord('h') or key == ord('?'):
			try:
				stdscr.clear()
				stdscr.addstr(1, 1, "aneris usage:", curses.A_BOLD|curses.color_pair(5))
				stdscr.addstr(2, 1, "=============", curses.A_BOLD|curses.color_pair(5))

				stdscr.addstr(4, 1, "tab          : toggle active panel", curses.A_BOLD|curses.color_pair(5))

				stdscr.addstr(6, 1, "cursor up    : previous task/day", curses.A_BOLD|curses.color_pair(5))
				stdscr.addstr(7, 1, "cursor down  : next task/day", curses.A_BOLD|curses.color_pair(5))
				stdscr.addstr(8, 1, "cursor left  : exit tp", curses.A_BOLD|curses.color_pair(5))
				stdscr.addstr(9, 1, "cursor right : edit project/task", curses.A_BOLD|curses.color_pair(5))

				stdscr.addstr(11, 1, "space        : toggle task visibility/next worker", curses.A_BOLD|curses.color_pair(5))

				stdscr.addstr(13, 1, "+            : increment project priority/task hours/hours committed", curses.A_BOLD|curses.color_pair(5))
				stdscr.addstr(14, 1, "-            : decrement project priority/task hours/hours committed", curses.A_BOLD|curses.color_pair(5))

				if(height > 20):
					stdscr.addstr(16, 1, "A            : add project", curses.A_BOLD|curses.color_pair(5))
					stdscr.addstr(17, 1, "a            : add task", curses.A_BOLD|curses.color_pair(5))
					stdscr.addstr(18, 1, "r            : remove project/task", curses.A_BOLD|curses.color_pair(5))

					stdscr.addstr(20, 1, "s            : save data", curses.A_BOLD|curses.color_pair(5))
				key=stdscr.getch()
			except curses.error:
				pass

		del edit_window
		del tasks_window
		del resources_window

	try:
		edit_window.clear()
		edit_window.addstr(0, 0, "saved at {0}".format(datetime.datetime.now()), curses.color_pair(2))
		edit_window.refresh()
	except curses.error:
		pass
	tasks.save()
	resources.save()
	time.sleep(1)

#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#=#
			
curses.wrapper(main_ui)

